@@ -9,6 +9,7 @@ from operator import attrgetter
 import datetime
 
 from ..parser import EXTENSION_MARKER
+from . import BaseType, format_bytes, ErrorWithLocation
 from . import EncodeError
 from . import DecodeError
 from . import OutOfDataError
@@ -168,7 +169,7 @@ class Encoder(object):
         self.append_non_negative_binary_integer(value, 8 * number_of_bytes)
 
     def __repr__(self):
-        return binascii.hexlify(self.as_bytearray()).decode('ascii')
+        return format_bytes(self.as_bytearray())
 
 
 class Decoder(object):
@@ -289,11 +290,10 @@ class Decoder(object):
         return bytes(tag)
 
 
-class Type(object):
+class Type(BaseType):
 
     def __init__(self, name, type_name, number, flags=0):
-        self.name = name
-        self.type_name = type_name
+        super().__init__(name, type_name)
         self.module_name = None
 
         if number is None:
@@ -301,9 +301,6 @@ class Type(object):
         else:
             self.tag = encode_tag(number, flags)
 
-        self.optional = False
-        self.default = None
-
     def set_tag(self, number, flags):
         if not Class.APPLICATION & flags:
             flags |= Class.CONTEXT_SPECIFIC
@@ -316,18 +313,6 @@ class Type(object):
     def set_restricted_to_range(self, minimum, maximum, has_extension_marker):
         pass
 
-    def set_default(self, value):
-        self.default = value
-
-    def get_default(self):
-        return self.default
-
-    def is_default(self, value):
-        return value == self.default
-
-    def has_default(self):
-        return self.default is not None
-
 
 class KnownMultiplierStringType(Type):
 
@@ -366,10 +351,6 @@ class KnownMultiplierStringType(Type):
 
         return decoder.read_bytes(number_of_bytes).decode(self.ENCODING)
 
-    def __repr__(self):
-        return '{}({})'.format(self.__class__.__name__,
-                               self.name)
-
 
 class MembersType(Type):
 
@@ -459,9 +440,11 @@ class MembersType(Type):
                     member.encode(data[name], encoder)
                 elif not member.is_default(data[name]) or encode_default:
                     member.encode(data[name], encoder)
-            except EncodeError as e:
-                e.location.append(member.name)
-                raise
+            except ErrorWithLocation as e:
+                # Add member location
+                e.add_location(member)
+                raise e
+
         elif member.optional or member.has_default():
             pass
         else:
@@ -493,15 +476,17 @@ class MembersType(Type):
         decoder.align()
 
         for member in self.root_members:
-            try:
-                if optionals.get(member, True):
+            if optionals.get(member, True):
+                try:
                     value = member.decode(decoder)
-                    values[member.name] = value
-                elif member.has_default():
-                    values[member.name] = member.default
-            except DecodeError as e:
-                e.location.append(member.name)
-                raise
+                except ErrorWithLocation as e:
+                    # Add member location
+                    e.add_location(member)
+                    raise e
+
+                values[member.name] = value
+            elif member.has_default():
+                values[member.name] = member.default
 
         return values
 
@@ -521,12 +506,12 @@ class MembersType(Type):
 
                 if i < len(self.additions):
                     addition = self.additions[i]
-
                     try:
                         decoded[addition.name] = addition.decode(decoder)
-                    except DecodeError as e:
-                        e.location.append(addition.name)
-                        raise
+                    except ErrorWithLocation as e:
+                        # Add member location
+                        e.add_location(addition)
+                        raise e
                 else:
                     decoder.skip_bits(8 * member_length)
 
@@ -582,9 +567,6 @@ class Boolean(Type):
     def decode(self, decoder):
         return bool(decoder.read_byte())
 
-    def __repr__(self):
-        return 'Boolean({})'.format(self.name)
-
 
 class Integer(Type):
 
@@ -648,9 +630,6 @@ class Integer(Type):
         else:
             return decoder.read_unsigned_integer()
 
-    def __repr__(self):
-        return 'Integer({})'.format(self.name)
-
 
 class Real(Type):
 
@@ -723,9 +702,6 @@ class Real(Type):
         else:
             return struct.unpack(self.fmt, decoder.read_bytes(self.length))[0]
 
-    def __repr__(self):
-        return 'Real({})'.format(self.name)
-
 
 class Null(Type):
 
@@ -738,9 +714,6 @@ class Null(Type):
     def decode(self, _decoder):
         return
 
-    def __repr__(self):
-        return 'Null({})'.format(self.name)
-
 
 class BitString(Type):
 
@@ -791,9 +764,6 @@ class BitString(Type):
 
         return (decoder.read_bytes(number_of_bytes), number_of_bits)
 
-    def __repr__(self):
-        return 'BitString({})'.format(self.name)
-
 
 class OctetString(Type):
 
@@ -825,9 +795,6 @@ class OctetString(Type):
 
         return decoder.read_bytes(number_of_bytes)
 
-    def __repr__(self):
-        return 'OctetString({})'.format(self.name)
-
 
 class ObjectIdentifier(Type):
 
@@ -847,9 +814,6 @@ class ObjectIdentifier(Type):
 
         return decode_object_identifier(bytearray(data), 0, len(data))
 
-    def __repr__(self):
-        return 'ObjectIdentifier({})'.format(self.name)
-
 
 class Enumerated(Type):
 
@@ -903,11 +867,7 @@ class Enumerated(Type):
         else:
             raise DecodeError(
                 'Expected enumeration value {}, but got {}.'.format(
-                    self.format_values(),
-                    value))
-
-    def __repr__(self):
-        return 'Enumerated({})'.format(self.name)
+                    self.format_values(), value))
 
 
 class Sequence(MembersType):
@@ -981,12 +941,9 @@ class Choice(Type):
         for member in members:
             tag_to_member[member.tag] = member
 
-    def format_tag(self, tag):
-        return binascii.hexlify(tag).decode('ascii')
-
     def format_tags(self):
         return format_or(
-            sorted([self.format_tag(member.tag) for member in self.members]))
+            sorted([format_bytes(member.tag) for member in self.members]))
 
     def format_names(self):
         return format_or(sorted([member.name for member in self.members]))
@@ -997,12 +954,23 @@ class Choice(Type):
         if name in self.name_to_root_member:
             member = self.name_to_root_member[name]
             encoder.append_bytes(member.tag)
-            self.encode_member(member, data[1], encoder)
+            try:
+                member.encode(data[1], encoder)
+            except ErrorWithLocation as e:
+                # Add member location
+                e.add_location(member)
+                raise e
+
         elif name in self.name_to_addition:
             member = self.name_to_addition[name]
             encoder.append_bytes(member.tag)
             addition_encoder = Encoder()
-            self.encode_member(member, data[1], addition_encoder)
+            try:
+                member.encode(data[1], addition_encoder)
+            except ErrorWithLocation as e:
+                # Add member location
+                e.add_location(member)
+                raise e
             encoder.append_length_determinant(addition_encoder.number_of_bytes())
             encoder += addition_encoder
         else:
@@ -1011,23 +979,33 @@ class Choice(Type):
                     self.format_names(),
                     data[0]))
 
-    def encode_member(self, member, data, encoder):
-        try:
-            member.encode(data, encoder)
-        except EncodeError as e:
-            e.location.append(member.name)
-            raise
+    # def encode_member(self, member, data, encoder):
+    #     try:
+    #         member.encode(data, encoder)
+    #     except EncodeError as e:
+    #         e.location.append(member.name)
+    #         raise
 
     def decode(self, decoder):
         tag = decoder.read_tag()
 
         if tag in self.tag_to_root_member:
             member = self.tag_to_root_member[tag]
-            decoded = member.decode(decoder)
+            try:
+                decoded = member.decode(decoder)
+            except ErrorWithLocation as e:
+                # Add member location
+                e.add_location(member)
+                raise e
         elif tag in self.tag_to_addition:
             member = self.tag_to_addition[tag]
             decoder.read_length_determinant()
-            decoded = member.decode(decoder)
+            try:
+                decoded = member.decode(decoder)
+            except ErrorWithLocation as e:
+                # Add member location
+                e.add_location(member)
+                raise e
         elif self.has_extension_marker:
             length = decoder.read_length_determinant()
             decoder.skip_bits(8 * length)
@@ -1036,8 +1014,7 @@ class Choice(Type):
         else:
             raise DecodeError(
                 "Expected choice member tag {}, but got '{}'.".format(
-                    self.format_tags(),
-                    self.format_tag(tag)))
+                    self.format_tags(), format_bytes(tag)))
 
         return (member.name, decoded)
 
@@ -1237,9 +1214,6 @@ class Any(Type):
     def decode(self, decoder):
         raise NotImplementedError('ANY is not yet implemented.')
 
-    def __repr__(self):
-        return 'Any({})'.format(self.name)
-
 
 class AnyDefinedBy(Type):
 
@@ -1257,11 +1231,8 @@ class AnyDefinedBy(Type):
     def decode(self, decoder):
         raise NotImplementedError('ANY DEFINED BY is not yet implemented.')
 
-    def __repr__(self):
-        return 'AnyDefinedBy({})'.format(self.name)
 
-
-class Recursive(Type, compiler.Recursive):
+class Recursive(compiler.Recursive, Type):
 
     def __init__(self, name, type_name, module_name):
         super(Recursive, self).__init__(name, 'RECURSIVE', None)
@@ -1283,22 +1254,28 @@ class Recursive(Type, compiler.Recursive):
     def decode(self, decoder):
         return self.inner.decode(decoder)
 
-    def __repr__(self):
-        return 'Recursive({})'.format(self.type_name)
-
 
 class CompiledType(compiler.CompiledType):
 
     def encode(self, data):
         encoder = Encoder()
-        self._type.encode(data, encoder)
+        try:
+            self._type.encode(data, encoder)
+        except ErrorWithLocation as e:
+            # Add member location
+            e.add_location(self._type)
+            raise e
 
         return encoder.as_bytearray()
 
     def decode(self, data):
         decoder = Decoder(bytearray(data))
-
-        return self._type.decode(decoder)
+        try:
+            return self._type.decode(decoder)
+        except ErrorWithLocation as e:
+            # Add member location
+            e.add_location(self._type)
+            raise e
 
 
 class Compiler(compiler.Compiler):
@@ -1503,5 +1480,5 @@ def compile_dict(specification, numeric_enums=False):
     return Compiler(specification, numeric_enums).process()
 
 
-def decode_length(_data):
+def decode_full_length(_data):
     raise DecodeError('Decode length is not supported for this codec.')
