@@ -9,6 +9,7 @@ import binascii
 import datetime
 
 from ..parser import EXTENSION_MARKER
+from . import BaseType, format_bytes, ErrorWithLocation
 from . import EncodeError
 from . import DecodeError
 from . import compiler
@@ -40,36 +41,20 @@ def indent_xml(element, indent, level=0):
             element.tail = i
 
 
-class Type(object):
+class Type(BaseType):
 
     def __init__(self, name, type_name):
-        self.name = name.replace(' ', '_')
-        self.type_name = type_name
-        self.optional = False
-        self.default = None
+        super().__init__(name.replace(' ', '_'), type_name)
 
     def set_size_range(self, minimum, maximum, has_extension_marker):
         pass
 
-    def set_default(self, value):
-        self.default = value
-
-    def get_default(self):
-        return self.default
-
-    def has_default(self):
-        return self.default is not None
-
-    def encode(self, data):
-        raise NotImplementedError('To be implemented by subclasses.')
-
     def encode_of(self, data):
+        # Used by ArrayType
         return self.encode(data)
 
-    def decode(self, element):
-        raise NotImplementedError('To be implemented by subclasses.')
-
     def decode_of(self, element):
+        # Used by ArrayType
         return self.decode(element)
 
 
@@ -118,9 +103,11 @@ class MembersType(Type):
             if name in data:
                 try:
                     member_element = member.encode(data[name])
-                except EncodeError as e:
-                    e.location.append(member.name)
-                    raise
+                except ErrorWithLocation as e:
+                    # Add member location
+                    e.add_location(member)
+                    raise e
+
             elif member.optional or member.has_default():
                 continue
             else:
@@ -142,7 +129,12 @@ class MembersType(Type):
             member_element = element.find(name)
 
             if member_element is not None:
-                value = member.decode(member_element)
+                try:
+                    value = member.decode(member_element)
+                except ErrorWithLocation as e:
+                    # Add member location
+                    e.add_location(member)
+                    raise e
                 values[name] = value
             elif member.optional:
                 pass
@@ -207,9 +199,6 @@ class Boolean(Type):
     def decode_of(self, element):
         return element.tag == 'true'
 
-    def __repr__(self):
-        return 'Boolean({})'.format(self.name)
-
 
 class Integer(Type):
 
@@ -225,9 +214,6 @@ class Integer(Type):
     def decode(self, element):
         return int(element.text)
 
-    def __repr__(self):
-        return 'Integer({})'.format(self.name)
-
 
 class Real(Type):
 
@@ -250,9 +236,6 @@ class Real(Type):
     def decode(self, element):
         return float(element.text)
 
-    def __repr__(self):
-        return 'Real({})'.format(self.name)
-
 
 class Null(Type):
 
@@ -265,9 +248,6 @@ class Null(Type):
     def decode(self, element):
         return None
 
-    def __repr__(self):
-        return 'Null({})'.format(self.name)
-
 
 class BitString(Type):
 
@@ -303,9 +283,6 @@ class BitString(Type):
 
         return (decoded, number_of_bits)
 
-    def __repr__(self):
-        return 'BitString({})'.format(self.name)
-
 
 class OctetString(Type):
 
@@ -316,7 +293,7 @@ class OctetString(Type):
         element = ElementTree.Element(self.name)
 
         if len(data) > 0:
-            element.text = binascii.hexlify(data).decode('ascii').upper()
+            element.text = format_bytes(data).upper()
 
         return element
 
@@ -324,11 +301,10 @@ class OctetString(Type):
         if element.text is None:
             return b''
         else:
+            if len(element.text) % 2:
+                return binascii.unhexlify(element.text.zfill(len(element.text)+1))
             return binascii.unhexlify(element.text)
 
-    def __repr__(self):
-        return 'OctetString({})'.format(self.name)
-
 
 class ObjectIdentifier(StringType):
 
@@ -388,8 +364,7 @@ class Enumerated(Type):
         else:
             raise DecodeError(
                 "Expected enumeration value {}, but got '{}'.".format(
-                    self.format_values(),
-                    value))
+                    self.format_values(), value))
 
     def encode_of(self, data):
         try:
@@ -410,11 +385,7 @@ class Enumerated(Type):
         except KeyError:
             raise DecodeError(
                 "Expected enumeration value {}, but got '{}'.".format(
-                    self.format_values(),
-                    value))
-
-    def __repr__(self):
-        return 'Enumerated({})'.format(self.name)
+                    self.format_values(), value))
 
 
 class Sequence(MembersType):
@@ -469,9 +440,10 @@ class Choice(Type):
 
         try:
             element.append(member.encode(data[1]))
-        except EncodeError as e:
-            e.location.append(member.name)
-            raise
+        except ErrorWithLocation as e:
+            # Add member location
+            e.add_location(member)
+            raise e
 
         return element
 
@@ -486,21 +458,30 @@ class Choice(Type):
         else:
             raise DecodeError(
                 "Expected choice {}, but got '{}'.".format(
-                    self.format_names(),
-                    name))
-
-        return (name, member.decode(member_element))
+                    self.format_names(), name))
+        try:
+            return (name, member.decode(member_element))
+        except ErrorWithLocation as e:
+            # Add member location
+            e.add_location(member)
+            raise e
 
     def encode_of(self, data):
         try:
             member = self.name_to_member[data[0]]
         except KeyError:
-            raise EncodeError(
+            e = EncodeError(
                 "Expected choice {}, but got '{}'.".format(
                     self.format_names(),
                     data[0]))
-
-        return member.encode(data[1])
+            # e.add_location(self.name)
+            raise e
+        try:
+            return member.encode(data[1])
+        except ErrorWithLocation as e:
+            # Add member location
+            e.add_location(member)
+            raise e
 
     def decode_of(self, element):
         name = element.tag
@@ -510,10 +491,13 @@ class Choice(Type):
         except KeyError:
             raise DecodeError(
                 "Expected choice {}, but got '{}'.".format(
-                    self.format_names(),
-                    name))
-
-        return (name, member.decode(element))
+                    self.format_names(), name))
+        try:
+            return (name, member.decode(element))
+        except ErrorWithLocation as e:
+            # Add member location
+            e.add_location(member)
+            raise e
 
     def __repr__(self):
         return 'Choice({}, [{}])'.format(
@@ -579,9 +563,6 @@ class UTCTime(Type):
     def decode(self, element):
         return utc_time_to_datetime(element.text)
 
-    def __repr__(self):
-        return 'UTCTime({})'.format(self.name)
-
 
 class GeneralizedTime(Type):
 
@@ -597,9 +578,6 @@ class GeneralizedTime(Type):
     def decode(self, element):
         return generalized_time_to_datetime(element.text)
 
-    def __repr__(self):
-        return 'GeneralizedTime({})'.format(self.name)
-
 
 class Date(StringType):
 
@@ -649,11 +627,8 @@ class Any(Type):
     def decode(self, element):
         raise NotImplementedError('ANY is not yet implemented.')
 
-    def __repr__(self):
-        return 'Any({})'.format(self.name)
 
-
-class Recursive(Type, compiler.Recursive):
+class Recursive(compiler.Recursive, Type):
 
     def __init__(self, name, type_name, module_name):
         super(Recursive, self).__init__(name, 'RECURSIVE')
@@ -673,14 +648,16 @@ class Recursive(Type, compiler.Recursive):
     def decode(self, element):
         return self._inner.decode(element)
 
-    def __repr__(self):
-        return 'Recursive({})'.format(self.name)
-
 
 class CompiledType(compiler.CompiledType):
 
     def encode(self, data, indent=None):
-        element = self._type.encode(data)
+        try:
+            element = self._type.encode(data)
+        except ErrorWithLocation as e:
+            # Add member location
+            e.add_location(self._type)
+            raise e
 
         if indent is not None:
             indent_xml(element, indent * " ")
@@ -689,8 +666,12 @@ class CompiledType(compiler.CompiledType):
 
     def decode(self, data):
         element = ElementTree.fromstring(data.decode('utf-8'))
-
-        return self._type.decode(element)
+        try:
+            return self._type.decode(element)
+        except ErrorWithLocation as e:
+            # Add member location
+            e.add_location(self._type)
+            raise e
 
 
 class Compiler(compiler.Compiler):
@@ -714,7 +695,7 @@ class Compiler(compiler.Compiler):
         elif type_name == 'SEQUENCE OF':
             element = type_descriptor['element']
             compiled = SequenceOf(name,
-                                  self.compile_type(element['type'],
+                                  self.compile_type(type_descriptor.get('element_name') or element['type'],
                                                     element,
                                                     module_name))
         elif type_name == 'SET':
@@ -725,7 +706,7 @@ class Compiler(compiler.Compiler):
         elif type_name == 'SET OF':
             element = type_descriptor['element']
             compiled = SetOf(name,
-                             self.compile_type(element['type'],
+                             self.compile_type(type_descriptor.get('element_name') or element['type'],
                                                element,
                                                module_name))
         elif type_name == 'CHOICE':
@@ -810,5 +791,5 @@ def compile_dict(specification, numeric_enums):
     return Compiler(specification, numeric_enums).process()
 
 
-def decode_length(_data):
+def decode_full_length(_data):
     raise DecodeError('Decode length is not supported for this codec.')
