@@ -331,8 +331,8 @@ class _Generator(Generator):
         if present_mask_length > 0:
             fmt = 'uint8_t {{}}[{}];'.format(present_mask_length)
             unique_present_mask = self.add_unique_variable(fmt, 'present_mask')
-
             start_set_byte = 0
+
             if extension_bit == 1 and len(type_.additions) > 0:
                 if_line = 'if({}) {{'.format(self.get_addition_present_condition(type_))
                 encode_lines.extend(textwrap.wrap(if_line, 100,
@@ -368,7 +368,7 @@ class _Generator(Generator):
                     encode_lines += [
                         'if (src_p->{}is_{}_present) {{'.format(
                             self.location_inner('', '.'),
-                            member.name),
+                            canonical(member.name)),
                         '    {} |= {}u;'.format(present_mask, mask),
                         '}',
                         ''
@@ -376,20 +376,41 @@ class _Generator(Generator):
                     decode_lines.append(
                         'dst_p->{0}is_{1}_present = (({2} & {3}u) == {3}u);'.format(
                             self.location_inner('', '.'),
-                            member.name,
+                            canonical(member.name),
                             present_mask,
                             mask))
                 else:
-                    encode_lines += [
-                        'if (src_p->{}{}{} != {}) {{'.format(
-                            self.location_inner('', '.'),
-                            member.name,
-                            '.value' if self.is_complex_user_type(member) else '',
-                            self.format_default(member)),
-                        '    {} |= {}u;'.format(present_mask, mask),
-                        '}',
-                        ''
-                    ]
+                    inner = '    {} |= {}u;'.format(present_mask, mask)
+
+                    if self.is_buffer_type(member):
+                        default_variable = canonical(member.name) + '_default'
+
+                        encode_lines += [
+                            'if ((memcmp(src_p->{}{}.buf, {}, sizeof({})) != 0) ||'.format(
+                                self.location_inner('', '.'),
+                                canonical(member.name),
+                                default_variable,
+                                default_variable,
+                                self.format_default(member)),
+                            '    (src_p->{}{}.length != sizeof({}))) {{'.format(
+                                self.location_inner('', '.'),
+                                canonical(member.name),
+                                default_variable),
+                            inner,
+                            '}',
+                            ''
+                        ]
+                    else:
+                        encode_lines += [
+                            'if (src_p->{}{}{} != {}) {{'.format(
+                                self.location_inner('', '.'),
+                                canonical(member.name),
+                                '.value' if self.is_complex_user_type(member) else '',
+                                self.format_default(member)),
+                            inner,
+                            '}',
+                            ''
+                        ]
 
             encode_lines += [
                 'encoder_append_bytes(encoder_p,',
@@ -732,9 +753,9 @@ class _Generator(Generator):
             member_checker = self.get_member_checker(checker,
                                                      member.name)
 
-            with self.asn1_members_backtrace_push(member.name):
+            with self.asn1_members_backtrace_push(canonical(member.name)):
                 with self.c_members_backtrace_push('value'):
-                    with self.c_members_backtrace_push(member.name):
+                    with self.c_members_backtrace_push(canonical(member.name)):
                         choice_encode_lines, choice_decode_lines = self.format_type_inner(
                             member,
                             member_checker)
@@ -757,7 +778,7 @@ class _Generator(Generator):
                 'break;'
             ]
             encode_lines += [
-                'case {}_choice_{}_e:'.format(self.location, member.name)
+                'case {}_choice_{}_e:'.format(self.location, canonical(member.name))
             ] + indent_lines(choice_encode_lines) + [
                 ''
             ]
@@ -765,7 +786,7 @@ class _Generator(Generator):
             choice_decode_lines = [
                 'dst_p->{} = {}_choice_{}_e;'.format(choice,
                                                      self.location,
-                                                     member.name)
+                                                     canonical(member.name))
             ] + choice_decode_lines + [
                 'break;'
             ]
@@ -814,9 +835,9 @@ class _Generator(Generator):
                     member_checker = self.get_member_checker(checker,
                                                              member.name)
 
-                    with self.asn1_members_backtrace_push(member.name):
+                    with self.asn1_members_backtrace_push(canonical(member.name)):
                         with self.c_members_backtrace_push('value'):
-                            with self.c_members_backtrace_push(member.name):
+                            with self.c_members_backtrace_push(canonical(member.name)):
                                 choice_type_lengths = self.get_encoded_type_lengths(
                                     member,
                                     member_checker)
@@ -828,7 +849,7 @@ class _Generator(Generator):
                                                          subsequent_indent=' ' * 4)
 
                     choice_length_lines += [
-                        'case {}_choice_{}_e:'.format(self.location, member.name)
+                        'case {}_choice_{}_e:'.format(self.location, canonical(member.name))
                     ] + indent_lines(wrapped_length_lines) + [
                         '    break;',
                         '']
@@ -1056,6 +1077,8 @@ class _Generator(Generator):
             return self.format_choice_inner(type_, checker)
         elif isinstance(type_, oer.OctetString):
             return self.format_octet_string_inner(checker)
+        elif isinstance(type_, oer.BitString):
+            return self.format_bit_string_inner(checker)
         elif isinstance(type_, oer.Enumerated):
             return self.format_enumerated_inner(type_)
         elif isinstance(type_, oer.Null):
@@ -1067,6 +1090,9 @@ class _Generator(Generator):
         return is_user_type(type_) and \
             not isinstance(type_, (oer.Integer, oer.Boolean, oer.Real, oer.Null))
 
+    def is_buffer_type(self, type_):
+        return isinstance(type_, oer.OctetString)
+
     def generate_helpers(self, definitions):
         helpers = []
 
