@@ -1,41 +1,41 @@
 EXPECTED = {'CAM-PDU-Descriptions': {'extensibility-implied': False,
-                          'imports': {'ITS-Container': ['ItsPduHeader',
+                          'imports': {'ITS-Container': ['AccelerationControl',
                                                         'CauseCode',
-                                                        'ReferencePosition',
-                                                        'AccelerationControl',
+                                                        'CenDsrcTollingZone',
+                                                        'ClosedLanes',
                                                         'Curvature',
                                                         'CurvatureCalculationMode',
-                                                        'Heading',
-                                                        'LanePosition',
-                                                        'EmergencyPriority',
-                                                        'EmbarkationStatus',
-                                                        'Speed',
-                                                        'DriveDirection',
-                                                        'LongitudinalAcceleration',
-                                                        'LateralAcceleration',
-                                                        'VerticalAcceleration',
-                                                        'StationType',
-                                                        'ExteriorLights',
                                                         'DangerousGoodsBasic',
-                                                        'SpecialTransportType',
-                                                        'LightBarSirenInUse',
-                                                        'VehicleRole',
-                                                        'VehicleLength',
-                                                        'VehicleWidth',
-                                                        'PathHistory',
-                                                        'RoadworksSubCauseCode',
-                                                        'ClosedLanes',
-                                                        'TrafficRule',
-                                                        'SpeedLimit',
-                                                        'SteeringWheelAngle',
-                                                        'PerformanceClass',
-                                                        'YawRate',
-                                                        'ProtectedCommunicationZone',
-                                                        'PtActivation',
+                                                        'DriveDirection',
+                                                        'EmbarkationStatus',
+                                                        'EmergencyPriority',
+                                                        'ExteriorLights',
+                                                        'Heading',
+                                                        'ItsPduHeader',
+                                                        'LanePosition',
+                                                        'LateralAcceleration',
                                                         'Latitude',
+                                                        'LightBarSirenInUse',
                                                         'Longitude',
+                                                        'LongitudinalAcceleration',
+                                                        'PathHistory',
+                                                        'PerformanceClass',
+                                                        'ProtectedCommunicationZone',
                                                         'ProtectedCommunicationZonesRSU',
-                                                        'CenDsrcTollingZone']},
+                                                        'PtActivation',
+                                                        'ReferencePosition',
+                                                        'RoadworksSubCauseCode',
+                                                        'SpecialTransportType',
+                                                        'Speed',
+                                                        'SpeedLimit',
+                                                        'StationType',
+                                                        'SteeringWheelAngle',
+                                                        'TrafficRule',
+                                                        'VehicleLength',
+                                                        'VehicleRole',
+                                                        'VehicleWidth',
+                                                        'VerticalAcceleration',
+                                                        'YawRate']},
                           'object-classes': {},
                           'object-sets': {},
                           'tags': 'AUTOMATIC',
