@@ -1,41 +1,35 @@
-RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
+EXPECTED = {'PKIX1Algorithms88': {'extensibility-implied': False,
                        'imports': {},
                        'object-classes': {},
                        'object-sets': {},
                        'tags': 'EXPLICIT',
                        'types': {'Characteristic-two': {'members': [{'name': 'm',
-                                                                     'optional': False,
                                                                      'type': 'INTEGER'},
                                                                     {'name': 'basis',
-                                                                     'optional': False,
-                                                                     'type': 'OBJECT IDENTIFIER'},
+                                                                     'type': 'OBJECT '
+                                                                             'IDENTIFIER'},
                                                                     {'choices': {},
                                                                      'name': 'parameters',
-                                                                     'optional': False,
-                                                                     'type': 'ANY DEFINED BY',
+                                                                     'type': 'ANY '
+                                                                             'DEFINED '
+                                                                             'BY',
                                                                      'value': 'basis'}],
                                                         'type': 'SEQUENCE'},
                                  'Curve': {'members': [{'name': 'a',
-                                                        'optional': False,
                                                         'type': 'FieldElement'},
                                                        {'name': 'b',
-                                                        'optional': False,
                                                         'type': 'FieldElement'},
                                                        {'name': 'seed',
                                                         'optional': True,
-                                                        'size': None,
                                                         'type': 'BIT STRING'}],
                                            'type': 'SEQUENCE'},
                                  'DHPublicKey': {'type': 'INTEGER'},
                                  'DSAPublicKey': {'type': 'INTEGER'},
                                  'DomainParameters': {'members': [{'name': 'p',
-                                                                   'optional': False,
                                                                    'type': 'INTEGER'},
                                                                   {'name': 'g',
-                                                                   'optional': False,
                                                                    'type': 'INTEGER'},
                                                                   {'name': 'q',
-                                                                   'optional': False,
                                                                    'type': 'INTEGER'},
                                                                   {'name': 'j',
                                                                    'optional': True,
@@ -45,105 +39,81 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                                                    'type': 'ValidationParms'}],
                                                       'type': 'SEQUENCE'},
                                  'Dss-Parms': {'members': [{'name': 'p',
-                                                            'optional': False,
                                                             'type': 'INTEGER'},
                                                            {'name': 'q',
-                                                            'optional': False,
                                                             'type': 'INTEGER'},
                                                            {'name': 'g',
-                                                            'optional': False,
                                                             'type': 'INTEGER'}],
                                                'type': 'SEQUENCE'},
                                  'Dss-Sig-Value': {'members': [{'name': 'r',
-                                                                'optional': False,
                                                                 'type': 'INTEGER'},
                                                                {'name': 's',
-                                                                'optional': False,
                                                                 'type': 'INTEGER'}],
                                                    'type': 'SEQUENCE'},
                                  'ECDSA-Sig-Value': {'members': [{'name': 'r',
-                                                                  'optional': False,
                                                                   'type': 'INTEGER'},
                                                                  {'name': 's',
-                                                                  'optional': False,
                                                                   'type': 'INTEGER'}],
                                                      'type': 'SEQUENCE'},
-                                 'ECPVer': {'type': 'INTEGER'},
+                                 'ECPVer': {'named-numbers': {'ecpVer1': 1},
+                                            'type': 'INTEGER'},
                                  'ECParameters': {'members': [{'name': 'version',
-                                                               'optional': False,
                                                                'type': 'ECPVer'},
                                                               {'name': 'fieldID',
-                                                               'optional': False,
                                                                'type': 'FieldID'},
                                                               {'name': 'curve',
-                                                               'optional': False,
                                                                'type': 'Curve'},
                                                               {'name': 'base',
-                                                               'optional': False,
                                                                'type': 'ECPoint'},
                                                               {'name': 'order',
-                                                               'optional': False,
                                                                'type': 'INTEGER'},
                                                               {'name': 'cofactor',
                                                                'optional': True,
                                                                'type': 'INTEGER'}],
                                                   'type': 'SEQUENCE'},
-                                 'ECPoint': {'size': None,
-                                             'type': 'OCTET STRING'},
+                                 'ECPoint': {'type': 'OCTET STRING'},
                                  'EcpkParameters': {'members': [{'name': 'ecParameters',
-                                                                 'optional': False,
                                                                  'type': 'ECParameters'},
                                                                 {'name': 'namedCurve',
-                                                                 'optional': False,
-                                                                 'type': 'OBJECT IDENTIFIER'},
+                                                                 'type': 'OBJECT '
+                                                                         'IDENTIFIER'},
                                                                 {'name': 'implicitlyCA',
-                                                                 'optional': False,
                                                                  'type': 'NULL'}],
                                                     'type': 'CHOICE'},
-                                 'FieldElement': {'size': None,
-                                                  'type': 'OCTET STRING'},
+                                 'FieldElement': {'type': 'OCTET STRING'},
                                  'FieldID': {'members': [{'name': 'fieldType',
-                                                          'optional': False,
-                                                          'type': 'OBJECT IDENTIFIER'},
+                                                          'type': 'OBJECT '
+                                                                  'IDENTIFIER'},
                                                          {'choices': {},
                                                           'name': 'parameters',
-                                                          'optional': False,
-                                                          'type': 'ANY DEFINED BY',
+                                                          'type': 'ANY DEFINED '
+                                                                  'BY',
                                                           'value': 'fieldType'}],
                                              'type': 'SEQUENCE'},
-                                 'KEA-Parms-Id': {'size': None,
-                                                  'type': 'OCTET STRING'},
+                                 'KEA-Parms-Id': {'type': 'OCTET STRING'},
                                  'Pentanomial': {'members': [{'name': 'k1',
-                                                              'optional': False,
                                                               'type': 'INTEGER'},
                                                              {'name': 'k2',
-                                                              'optional': False,
                                                               'type': 'INTEGER'},
                                                              {'name': 'k3',
-                                                              'optional': False,
                                                               'type': 'INTEGER'}],
                                                  'type': 'SEQUENCE'},
                                  'Prime-p': {'type': 'INTEGER'},
                                  'RSAPublicKey': {'members': [{'name': 'modulus',
-                                                               'optional': False,
                                                                'type': 'INTEGER'},
                                                               {'name': 'publicExponent',
-                                                               'optional': False,
                                                                'type': 'INTEGER'}],
                                                   'type': 'SEQUENCE'},
                                  'Trinomial': {'type': 'INTEGER'},
                                  'ValidationParms': {'members': [{'name': 'seed',
-                                                                  'optional': False,
-                                                                  'size': None,
-                                                                  'type': 'BIT STRING'},
+                                                                  'type': 'BIT '
+                                                                          'STRING'},
                                                                  {'name': 'pgenCounter',
-                                                                  'optional': False,
                                                                   'type': 'INTEGER'}],
                                                      'type': 'SEQUENCE'}},
                        'values': {'ansi-X9-62': {'type': 'OBJECT IDENTIFIER',
                                                  'value': [('iso', 1),
-                                                           ('member-body',
-                                                            2),
+                                                           ('member-body', 2),
                                                            ('us', 840),
                                                            10045]},
                                   'c-TwoCurve': {'type': 'OBJECT IDENTIFIER',
@@ -155,11 +125,9 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                   'c2onb191v5': {'type': 'OBJECT IDENTIFIER',
                                                  'value': ['c-TwoCurve', 9]},
                                   'c2onb239v4': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           14]},
+                                                 'value': ['c-TwoCurve', 14]},
                                   'c2onb239v5': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           15]},
+                                                 'value': ['c-TwoCurve', 15]},
                                   'c2pnb163v1': {'type': 'OBJECT IDENTIFIER',
                                                  'value': ['c-TwoCurve', 1]},
                                   'c2pnb163v2': {'type': 'OBJECT IDENTIFIER',
@@ -169,17 +137,13 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                   'c2pnb176w1': {'type': 'OBJECT IDENTIFIER',
                                                  'value': ['c-TwoCurve', 4]},
                                   'c2pnb208w1': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           10]},
+                                                 'value': ['c-TwoCurve', 10]},
                                   'c2pnb272w1': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           16]},
+                                                 'value': ['c-TwoCurve', 16]},
                                   'c2pnb304w1': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           17]},
+                                                 'value': ['c-TwoCurve', 17]},
                                   'c2pnb368w1': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           19]},
+                                                 'value': ['c-TwoCurve', 19]},
                                   'c2tnb191v1': {'type': 'OBJECT IDENTIFIER',
                                                  'value': ['c-TwoCurve', 5]},
                                   'c2tnb191v2': {'type': 'OBJECT IDENTIFIER',
@@ -187,24 +151,21 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                   'c2tnb191v3': {'type': 'OBJECT IDENTIFIER',
                                                  'value': ['c-TwoCurve', 7]},
                                   'c2tnb239v1': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           11]},
+                                                 'value': ['c-TwoCurve', 11]},
                                   'c2tnb239v2': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           12]},
+                                                 'value': ['c-TwoCurve', 12]},
                                   'c2tnb239v3': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           13]},
+                                                 'value': ['c-TwoCurve', 13]},
                                   'c2tnb359v1': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           18]},
+                                                 'value': ['c-TwoCurve', 18]},
                                   'c2tnb431r1': {'type': 'OBJECT IDENTIFIER',
-                                                 'value': ['c-TwoCurve',
-                                                           20]},
-                                  'characteristic-two-field': {'type': 'OBJECT IDENTIFIER',
+                                                 'value': ['c-TwoCurve', 20]},
+                                  'characteristic-two-field': {'type': 'OBJECT '
+                                                                       'IDENTIFIER',
                                                                'value': ['id-fieldType',
                                                                          2]},
-                                  'dhpublicnumber': {'type': 'OBJECT IDENTIFIER',
+                                  'dhpublicnumber': {'type': 'OBJECT '
+                                                             'IDENTIFIER',
                                                      'value': [('iso', 1),
                                                                ('member-body',
                                                                 2),
@@ -214,17 +175,18 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                                                ('number-type',
                                                                 2),
                                                                1]},
-                                  'ecdsa-with-SHA1': {'type': 'OBJECT IDENTIFIER',
+                                  'ecdsa-with-SHA1': {'type': 'OBJECT '
+                                                              'IDENTIFIER',
                                                       'value': ['id-ecSigType',
                                                                 1]},
                                   'ellipticCurve': {'type': 'OBJECT IDENTIFIER',
                                                     'value': ['ansi-X9-62',
-                                                              ('curves',
-                                                               3)]},
+                                                              ('curves', 3)]},
                                   'gnBasis': {'type': 'OBJECT IDENTIFIER',
                                               'value': ['id-characteristic-two-basis',
                                                         1]},
-                                  'id-characteristic-two-basis': {'type': 'OBJECT IDENTIFIER',
+                                  'id-characteristic-two-basis': {'type': 'OBJECT '
+                                                                          'IDENTIFIER',
                                                                   'value': ['characteristic-two-field',
                                                                             ('basisType',
                                                                              3)]},
@@ -235,19 +197,19 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                                        ('x9-57', 10040),
                                                        ('x9algorithm', 4),
                                                        1]},
-                                  'id-dsa-with-sha1': {'type': 'OBJECT IDENTIFIER',
-                                                       'value': [('iso',
-                                                                  1),
+                                  'id-dsa-with-sha1': {'type': 'OBJECT '
+                                                               'IDENTIFIER',
+                                                       'value': [('iso', 1),
                                                                  ('member-body',
                                                                   2),
-                                                                 ('us',
-                                                                  840),
+                                                                 ('us', 840),
                                                                  ('x9-57',
                                                                   10040),
                                                                  ('x9algorithm',
                                                                   4),
                                                                  3]},
-                                  'id-ecPublicKey': {'type': 'OBJECT IDENTIFIER',
+                                  'id-ecPublicKey': {'type': 'OBJECT '
+                                                             'IDENTIFIER',
                                                      'value': ['id-publicKeyType',
                                                                1]},
                                   'id-ecSigType': {'type': 'OBJECT IDENTIFIER',
@@ -256,9 +218,9 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                                               4)]},
                                   'id-fieldType': {'type': 'OBJECT IDENTIFIER',
                                                    'value': ['ansi-X9-62',
-                                                             ('fieldType',
-                                                              1)]},
-                                  'id-keyExchangeAlgorithm': {'type': 'OBJECT IDENTIFIER',
+                                                             ('fieldType', 1)]},
+                                  'id-keyExchangeAlgorithm': {'type': 'OBJECT '
+                                                                      'IDENTIFIER',
                                                               'value': [2,
                                                                         16,
                                                                         840,
@@ -268,7 +230,8 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                                                         1,
                                                                         1,
                                                                         22]},
-                                  'id-publicKeyType': {'type': 'OBJECT IDENTIFIER',
+                                  'id-publicKeyType': {'type': 'OBJECT '
+                                                               'IDENTIFIER',
                                                        'value': ['ansi-X9-62',
                                                                  ('keyType',
                                                                   2)]},
@@ -287,7 +250,8 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                                     ('rsadsi', 113549),
                                                     ('digestAlgorithm', 2),
                                                     2]},
-                                  'md2WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
+                                  'md2WithRSAEncryption': {'type': 'OBJECT '
+                                                                   'IDENTIFIER',
                                                            'value': ['pkcs-1',
                                                                      2]},
                                   'md5': {'type': 'OBJECT IDENTIFIER',
@@ -297,7 +261,8 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                                     ('rsadsi', 113549),
                                                     ('digestAlgorithm', 2),
                                                     5]},
-                                  'md5WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
+                                  'md5WithRSAEncryption': {'type': 'OBJECT '
+                                                                   'IDENTIFIER',
                                                            'value': ['pkcs-1',
                                                                      4]},
                                   'pkcs-1': {'type': 'OBJECT IDENTIFIER',
@@ -311,8 +276,7 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                               'value': ['id-characteristic-two-basis',
                                                         3]},
                                   'prime-field': {'type': 'OBJECT IDENTIFIER',
-                                                  'value': ['id-fieldType',
-                                                            1]},
+                                                  'value': ['id-fieldType', 1]},
                                   'prime192v1': {'type': 'OBJECT IDENTIFIER',
                                                  'value': ['primeCurve', 1]},
                                   'prime192v2': {'type': 'OBJECT IDENTIFIER',
@@ -332,9 +296,10 @@ RFC3279 = {'PKIX1Algorithms88': {'extensibility-implied': False,
                                                            ('prime', 1)]},
                                   'rsaEncryption': {'type': 'OBJECT IDENTIFIER',
                                                     'value': ['pkcs-1', 1]},
-                                  'sha1WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
+                                  'sha1WithRSAEncryption': {'type': 'OBJECT '
+                                                                    'IDENTIFIER',
                                                             'value': ['pkcs-1',
                                                                       5]},
                                   'tpBasis': {'type': 'OBJECT IDENTIFIER',
                                               'value': ['id-characteristic-two-basis',
-                                                        2]}}}}
+                                                        2]}}}}
\ No newline at end of file
