@@ -1,14 +1,14 @@
 EXPECTED = {'PKIXAttributeCertificate': {'extensibility-implied': False,
-                              'imports': {'PKIX1Explicit88': ['Attribute',
-                                                              'AlgorithmIdentifier',
+                              'imports': {'PKIX1Explicit88': ['AlgorithmIdentifier',
+                                                              'Attribute',
                                                               'CertificateSerialNumber',
                                                               'Extensions',
                                                               'UniqueIdentifier',
-                                                              'id-pkix',
-                                                              'id-pe',
-                                                              'id-kp',
                                                               'id-ad',
-                                                              'id-at'],
+                                                              'id-at',
+                                                              'id-kp',
+                                                              'id-pe',
+                                                              'id-pkix'],
                                           'PKIX1Implicit88': ['GeneralName',
                                                               'GeneralNames',
                                                               'id-ce']},
