@@ -1,13 +1,13 @@
 EXPECTED = {'PKIXCRMF-2005': {'extensibility-implied': False,
                    'imports': {'CryptographicMessageSyntax2004': ['EnvelopedData'],
-                               'PKIX1Explicit88': ['Version',
-                                                   'AlgorithmIdentifier',
-                                                   'Name',
-                                                   'Time',
-                                                   'SubjectPublicKeyInfo',
+                               'PKIX1Explicit88': ['AlgorithmIdentifier',
+                                                   'Attribute',
                                                    'Extensions',
+                                                   'Name',
+                                                   'SubjectPublicKeyInfo',
+                                                   'Time',
                                                    'UniqueIdentifier',
-                                                   'Attribute'],
+                                                   'Version'],
                                'PKIX1Implicit88': ['GeneralName']},
                    'object-classes': {},
                    'object-sets': {},
