@@ -63,7 +63,8 @@ EXPECTED = {'InformationObject': {'extensibility-implied': False,
                                                     {'name': 'value',
                                                      'table': ['GCs', ['id']],
                                                      'type': 'GC.&Value'},
-                                                    {'name': 'a',
+                                                    {'actual-parameters': ['{'],
+                                                     'name': 'a',
                                                      'type': 'E1'}],
                                         'type': 'SEQUENCE'},
                                  'D2': {'members': [{'name': 'id',
@@ -81,6 +82,7 @@ EXPECTED = {'InformationObject': {'extensibility-implied': False,
                                                     {'name': 'value',
                                                      'table': ['Param', ['id']],
                                                      'type': 'GC.&Value'}],
+                                        'parameters': ['Param'],
                                         'type': 'SEQUENCE'},
                                  'ErrorReturn': {'members': [{'name': 'errorCategory',
                                                               'table': {'type': 'ErrorSet'},
