@@ -381,6 +381,7 @@ EXPECTED = {'X680': {'extensibility-implied': False,
                     'Keywords-E-2-11': {'element': {'type': 'VisibleString'},
                                         'type': 'SET OF'},
                     'Keywords2-E-2-11': {'element': {'type': 'VisibleString'},
+                                         'element_name': 'keyword',
                                          'type': 'SET OF'},
                     'MaritalStatus-E-2-3-a': {'type': 'ENUMERATED',
                                               'values': [('single', 0),
@@ -420,6 +421,7 @@ EXPECTED = {'X680': {'extensibility-implied': False,
                     'NamesOfMemberNations-E-2-10': {'element': {'type': 'VisibleString'},
                                                     'type': 'SEQUENCE OF'},
                     'NamesOfMemberNations2-E-2-10': {'element': {'type': 'VisibleString'},
+                                                    'element_name': 'memberNation',
                                                      'type': 'SEQUENCE OF'},
                     'NamesOfOfficers-E-2-10': {'members': [{'name': 'president',
                                                             'type': 'VisibleString'},
