@@ -142,14 +142,14 @@ class Asn1ToolsJerTest(unittest.TestCase):
             foo.encode('A', 'c')
 
         self.assertEqual(str(cm.exception),
-                         "Expected enumeration value 'a' or 'b', but got 'c'.")
+                         "A: Expected enumeration value 'a' or 'b', but got 'c'.")
 
         # Decode error.
         with self.assertRaises(asn1tools.DecodeError) as cm:
             foo.decode('A', b'"c"')
 
         self.assertEqual(str(cm.exception),
-                         "Expected enumeration value 'a' or 'b', but got 'c'.")
+                         "A: Expected enumeration value 'a' or 'b', but got 'c'.")
 
     def test_sequence(self):
         foo = asn1tools.compile_string(
@@ -189,7 +189,7 @@ class Asn1ToolsJerTest(unittest.TestCase):
 
         self.assertEqual(
             str(cm.exception),
-            "Sequence member 'b' not found in {'a': 1}.")
+            "C: Sequence member 'b' not found in {'a': 1}.")
 
     def test_sequence_of(self):
         foo = asn1tools.compile_string(
@@ -247,14 +247,14 @@ class Asn1ToolsJerTest(unittest.TestCase):
             foo.encode('A', ('c', None))
 
         self.assertEqual(str(cm.exception),
-                         "Expected choice 'a' or 'b', but got 'c'.")
+                         "A: Expected choice 'a' or 'b', but got 'c'.")
 
         # Decode error.
         with self.assertRaises(asn1tools.DecodeError) as cm:
             foo.decode('A', b'{"c": null}')
 
         self.assertEqual(str(cm.exception),
-                         "Expected choice 'a' or 'b', but got 'c'.")
+                         "A: Expected choice 'a' or 'b', but got 'c'.")
 
     def test_utf8_string(self):
         foo = asn1tools.compile_string(
@@ -804,32 +804,6 @@ class Asn1ToolsJerTest(unittest.TestCase):
         for type_name, decoded, encoded in datas:
             self.assert_encode_decode_string(foo, type_name, decoded, encoded)
 
-    def test_error_out_of_data(self):
-        foo = asn1tools.compile_string(
-            "Foo DEFINITIONS AUTOMATIC TAGS ::= "
-            "BEGIN "
-            "A ::= INTEGER "
-            "B ::= SEQUENCE { "
-            "  a SEQUENCE { "
-            "    b BOOLEAN, "
-            "    c INTEGER "
-            "  } "
-            "} "
-            "END",
-            'uper')
-
-        datas = [
-            ('A', b'',         'out of data at bit offset 0 (0.0 bytes)'),
-            ('B', b'\x00',     'a: c: out of data at bit offset 1 (0.1 bytes)'),
-            ('B', b'\x80\x80', 'a: c: out of data at bit offset 9 (1.1 bytes)')
-        ]
-
-        for type_name, encoded, message in datas:
-            with self.assertRaises(asn1tools.codecs.per.OutOfDataError) as cm:
-                foo.decode(type_name, encoded)
-
-            self.assertEqual(str(cm.exception), message)
-
     def test_indent(self):
         foo = asn1tools.compile_string(
             "Foo DEFINITIONS AUTOMATIC TAGS ::= "
