@@ -243,6 +243,27 @@ class Asn1ToolsParseTest(unittest.TestCase):
 
         self.assertEqual(actual, expected)
 
+    def test_parse_with_successors_descendants(self):
+        actual = asn1tools.parse_string('A DEFINITIONS ::= BEGIN '
+                                        'IMPORTS '
+                                        'a FROM B WITH SUCCESSORS '
+                                        'c, d FROM E {iso(1)} WITH DESCENDANTS ; '
+                                        'END')
+        expected = {
+            'A': {
+                'extensibility-implied': False,
+                'imports': {
+                    'B': ['a'],
+                    'E': ['c', 'd']
+                },
+                'object-classes': {},
+                'object-sets': {},
+                'types': {},
+                'values': {}
+            }
+        }
+        self.assertEqual(actual, expected)
+
     def test_parse_keyword_in_type_name(self):
         actual = asn1tools.parse_string('A DEFINITIONS ::= BEGIN '
                                         'ENDa ::= INTEGER '
