@@ -90,12 +90,15 @@ class Asn1ToolsXerTest(Asn1ToolsBaseTest):
 
         datas = [
             ('A',         b'', b'<A />'),
+            ('A', b'\x01\x23', b'<A>0123</A>'),
             ('A', b'\x40\x80', b'<A>4080</A>')
         ]
 
         for type_name, decoded, encoded in datas:
             self.assert_encode_decode_string(foo, type_name, decoded, encoded)
 
+        self.assertEqual(b'\x01\x23', foo.decode('A', b'<A>123</A>'))
+
     def test_object_identifier(self):
         foo = asn1tools.compile_string(
             "Foo DEFINITIONS AUTOMATIC TAGS ::= "
@@ -115,7 +118,7 @@ class Asn1ToolsXerTest(Asn1ToolsBaseTest):
             foo.decode('A', b'<A></A>')
 
         self.assertEqual(str(cm.exception),
-                         "Expected an OBJECT IDENTIFIER, but got ''.")
+                         "A: Expected an OBJECT IDENTIFIER, but got ''.")
 
     def test_external(self):
         foo = asn1tools.compile_string(
@@ -157,7 +160,7 @@ class Asn1ToolsXerTest(Asn1ToolsBaseTest):
 
         self.assertEqual(
             str(cm.exception),
-            "Expected enumeration value 'r' or 't', but got 'foo'.")
+            "A: Expected enumeration value 'r' or 't', but got 'foo'.")
 
         # Decode error.
         with self.assertRaises(asn1tools.DecodeError) as cm:
@@ -165,7 +168,7 @@ class Asn1ToolsXerTest(Asn1ToolsBaseTest):
 
         self.assertEqual(
             str(cm.exception),
-            "Expected enumeration value 'r' or 't', but got 'bar'.")
+            "A: Expected enumeration value 'r' or 't', but got 'bar'.")
 
         # Encode of error.
         with self.assertRaises(asn1tools.EncodeError) as cm:
@@ -173,7 +176,7 @@ class Asn1ToolsXerTest(Asn1ToolsBaseTest):
 
         self.assertEqual(
             str(cm.exception),
-            "Expected enumeration value 'a', but got 'foo'.")
+            "B: Expected enumeration value 'a', but got 'foo'.")
 
         # Decode of error.
         with self.assertRaises(asn1tools.DecodeError) as cm:
@@ -181,7 +184,7 @@ class Asn1ToolsXerTest(Asn1ToolsBaseTest):
 
         self.assertEqual(
             str(cm.exception),
-            "Expected enumeration value 'a', but got 'bar'.")
+            "B: Expected enumeration value 'a', but got 'bar'.")
 
     def test_sequence(self):
         foo = asn1tools.compile_string(
@@ -226,6 +229,8 @@ class Asn1ToolsXerTest(Asn1ToolsBaseTest):
             "K ::= SEQUENCE OF OBJECT IDENTIFIER "
             "L ::= SEQUENCE OF SEQUENCE OF NULL "
             "M ::= SEQUENCE OF SET OF NULL "
+            "N ::= SEQUENCE OF a INTEGER "
+            "O ::= SET OF a INTEGER "
             "END",
             'xer')
 
@@ -250,7 +255,11 @@ class Asn1ToolsXerTest(Asn1ToolsBaseTest):
              b'<L><SEQUENCE_OF><NULL /></SEQUENCE_OF><SEQUENCE_OF /></L>'),
             ('M',
              [[None], []],
-             b'<M><SET_OF><NULL /></SET_OF><SET_OF /></M>')
+             b'<M><SET_OF><NULL /></SET_OF><SET_OF /></M>'),
+            ('N',               [], b'<N />'),
+            ('N',           [1, 4], b'<N><a>1</a><a>4</a></N>'),
+            ('O',               [], b'<O />'),
+            ('O',           [1, 4], b'<O><a>1</a><a>4</a></O>'),
         ]
 
         for type_name, decoded, encoded in datas:
@@ -285,28 +294,28 @@ class Asn1ToolsXerTest(Asn1ToolsBaseTest):
             foo.encode('A', ('d', None))
 
         self.assertEqual(str(cm.exception),
-                         "Expected choice 'a', 'b' or 'c', but got 'd'.")
+                         "A: Expected choice 'a', 'b' or 'c', but got 'd'.")
 
         # Decode error.
         with self.assertRaises(asn1tools.DecodeError) as cm:
             foo.decode('A', b'<A><d><true /></d></A>')
 
         self.assertEqual(str(cm.exception),
-                         "Expected choice 'a', 'b' or 'c', but got 'd'.")
+                         "A: Expected choice 'a', 'b' or 'c', but got 'd'.")
 
         # Encode of error.
         with self.assertRaises(asn1tools.EncodeError) as cm:
             foo.encode('B', [('d', None)])
 
         self.assertEqual(str(cm.exception),
-                         "Expected choice 'a', 'b' or 'c', but got 'd'.")
+                         "B: Expected choice 'a', 'b' or 'c', but got 'd'.")
 
         # Decode of error.
         with self.assertRaises(asn1tools.DecodeError) as cm:
             foo.decode('B', b'<A><d><true /></d></A>')
 
         self.assertEqual(str(cm.exception),
-                         "Expected choice 'a', 'b' or 'c', but got 'd'.")
+                         "B: Expected choice 'a', 'b' or 'c', but got 'd'.")
 
     def test_utf8_string(self):
         foo = asn1tools.compile_string(
@@ -429,7 +438,7 @@ class Asn1ToolsXerTest(Asn1ToolsBaseTest):
 
         self.assertEqual(
             str(cm.exception),
-            "Sequence member 'id' not found in {'question': 'Is 1+1=3?'}.")
+            "Question: Sequence member 'id' not found in {'question': 'Is 1+1=3?'}.")
 
     def test_decode_length(self):
         foo = asn1tools.compile_files('tests/files/foo.asn', 'xer')
